@@ -11,16 +11,18 @@ pub use axum_core::extract::rejection::*;
 
 #[cfg(feature = "json")]
 define_rejection! {
-    #[status = BAD_REQUEST]
+    #[status = UNPROCESSABLE_ENTITY]
     #[body = "Failed to parse the request body as JSON"]
     #[cfg_attr(docsrs, doc(cfg(feature = "json")))]
     /// Rejection type for [`Json`](super::Json).
     pub struct InvalidJsonBody(Error);
 }
 
+#[cfg(feature = "json")]
 define_rejection! {
-    #[status = BAD_REQUEST]
+    #[status = UNSUPPORTED_MEDIA_TYPE]
     #[body = "Expected request with `Content-Type: application/json`"]
+    #[cfg_attr(docsrs, doc(cfg(feature = "json")))]
     /// Rejection type for [`Json`](super::Json) used if the `Content-Type`
     /// header is missing.
     pub struct MissingJsonContentType;
@@ -59,7 +61,7 @@ define_rejection! {
 }
 
 define_rejection! {
-    #[status = BAD_REQUEST]
+    #[status = UNSUPPORTED_MEDIA_TYPE]
     #[body = "Form requests must have `Content-Type: x-www-form-urlencoded`"]
     /// Rejection type used if you try and extract the request more than once.
     pub struct InvalidFormContentType;
@@ -88,7 +90,7 @@ impl FailedToDeserializeQueryString {
 impl IntoResponse for FailedToDeserializeQueryString {
     fn into_response(self) -> Response {
         let mut res = Response::new(boxed(Full::from(self.to_string())));
-        *res.status_mut() = http::StatusCode::BAD_REQUEST;
+        *res.status_mut() = http::StatusCode::UNPROCESSABLE_ENTITY;
         res
     }
 }
@@ -243,5 +245,4 @@ where
 }
 
 #[cfg(feature = "headers")]
-#[cfg_attr(docsrs, doc(cfg(feature = "headers")))]
 pub use super::typed_header::{TypedHeaderRejection, TypedHeaderRejectionReason};
